@@ -7,11 +7,11 @@ use Unicode::String;
 use overload
   'int' => sub { length $_[0]->getValue },
   '0+'  => sub { length $_[0]->getValue },
-;
+  ;
 
 sub setValue {
 	my ( $this, $value ) = @_;
-	$this->X3DField::setValue("$value");
+	$this->X3DField::setValue( defined $value ? "$value" : $this->getInitialValue );
 }
 
 sub toString { sprintf "%s", $_[0]->getValue }
