@@ -1,10 +1,8 @@
 package Weed::FieldTypes::SFVec4d;
 
-our $VERSION = '0.009';
-
 use Weed 'SFVec4d : X3DField { 0 0 0 0 }';
 
-use base 'Weed::BaseFieldTypes::Vector';
+use base 'Weed::FieldTypes::BaseFieldTypes::SFVector';
 
 sub x : lvalue { $_[0]->[0] }
 
