@@ -1,53 +1,37 @@
 package Weed::Hash;
 
-our $VERSION = '0.009';
-
-use Weed 'X3DHash { }', 'isHash';
+use Weed 'X3DHash { }';
 
 use overload
   'bool' => 'getSize',
-
-  'int' => 'getSize',
-  '0+'  => 'getSize',
-  #  '<=>' => sub { warn },
-  #  'cmp' => sub { warn },
-
-  '@{}' => 'getValues',
-  ;
+  
+  'int'  => 'getSize',
+  '0+'   => 'getSize',
+   ;
 
 sub new {
-	my $self = $_[0];
-	my $type = ref($self) || $self;
-	return bless $_[1] || {}, $type;
+	my $this = shift->NEW;
+	return $this;
 }
 
-sub getClone {
-	my $clone = $_[0]->new;
-	%$clone = %{ $_[0] };
-	return $clone;
-}
+#sub getClone { $_[0]->new( $_[0]->getValue ) }
 
 sub getKeys   { new X3DArray [ keys( %{ $_[0] } ) ] }
 sub getValues { new X3DArray [ values( %{ $_[0] } ) ] }
 
-sub getSize { scalar keys %{ $_[0] } }
-
-sub isHash {
-	UNIVERSAL::isa( $_[0], __PACKAGE__ )
-	  or
-	  UNIVERSAL::isa( $_[0], 'HASH' )
-}
-
 sub clear { %{ $_[0] } = () }
 
+sub getSize { scalar keys %{ $_[0] } }
+
 sub toString {
 	my $this = shift;
 
 	my $string = "";
 
+	$string .= X3DGenerator->indent;
 	$string .= X3DGenerator->open_brace;
 
-	if (%$this) {
+	if ( keys %$this ) {
 		$string .= X3DGenerator->tidy_break;
 		X3DGenerator->inc;
 		while ( my ( $key, $value ) = each %$this ) {
@@ -56,7 +40,7 @@ sub toString {
 			$string .= X3DGenerator->space;
 			$string .= '=>';
 			$string .= X3DGenerator->space;
-			$string .= "$value";
+			$string .= $value;
 			$string .= X3DGenerator->tidy_break;
 		}
 		X3DGenerator->dec;
