@@ -1,12 +1,16 @@
 package Weed::Package;
 use Weed::Perl;
 
+#use Package::Generator;
 #Symbol::delete_package wipes out a whole package namespace. Note this routine is not exported by default--you may want to import it explicitly.
 
-use Carp ();
+use Package::Alias X3DPackage => __PACKAGE__;
 
+use Carp ();
 use Class::ISA;
 
+use Weed::Parse::Concept;
+
 our $_space     = qr/\s+/so;
 our $_type_name = qr/^([\$\@%&*]?)(.*)/so;
 
@@ -14,7 +18,7 @@ sub import {
 	my $to = shift;
 
 	return unless @_;
-	#Carp::carp ( "Weed::Package::import" );
+	#Carp::carp ( "X3DPackage::import" );
 
 	my $alias = shift;
 
@@ -25,54 +29,81 @@ sub import {
 
 	if ( $to eq __PACKAGE__ ) {    # use package 'newname', @import;
 		my $original = caller;
-		return Weed::Package::base( $alias, $original, @_ );
+		return X3DPackage::base( $alias, $original, @_ );
 	}
-	else {                         # Weed::Package::import
-		return Weed::Package::_import( $to, $alias, @_ );
+	else {                         # X3DPackage::import
+		return X3DPackage::_import( $to, $alias, @_ );
 	}
 }
 
-sub name { ref( $_[0] ) || $_[0] }
-
 sub exists { UNIVERSAL::can( $_[0], 'can' ) ? YES: NO }
 
-sub superpath          { Class::ISA::super_path( Weed::Package::name(shift) ) }
-sub self_and_superpath { Class::ISA::self_and_super_path( Weed::Package::name(shift) ) }
+sub createType {
+	my ( $package, $base, $declaration, @imports ) = @_;
+
+	#printf "X3DUniversal createType %s %s\n", $package, $base;
+
+	my $description = Weed::Parse::Concept::parse($declaration);
+	if ( ref $description ) {
+
+		my $typeName = $description->{typeName};
+
+		X3DPackage::setBase( $typeName, $package, @imports );
+		X3DPackage::setSupertypes( $typeName,
+			@{ $description->{supertypes} } ?
+			  @{ $description->{supertypes} } :
+			  $base
+		);
+		X3DPackage::setBase( $typeName, $description->{base} );
+
+		#printf "X3DUniversal createType %s : %s %s\n", $typeName, $package, $base;
+		X3DPackage::Scalar( $typeName, "Description" ) = $description;
+
+		$typeName->setDescription($description)
+		  if $typeName->can('setDescription');
+
+	} else {
+		Carp::croak "Error Parse::Concept: '$declaration'\n", $@ if $@;
+	}
+
+	return;
+}
+
+sub getName { ref( $_[0] ) || $_[0] }
+
+sub getSuperpath          { Class::ISA::super_path( X3DPackage::getName(shift) ) }
+sub getSelfAndSuperpath { Class::ISA::self_and_super_path( X3DPackage::getName(shift) ) }
 
 #&\w(\w|::)*>|<\w(\w|::)*(?=\s*[\(\);])
 
-sub supertype {
-	my @path = Class::ISA::super_path( Weed::Package::name(shift) );
+sub getSupertype {
+	my @path = Class::ISA::super_path( X3DPackage::getName(shift) );
 	return shift @path;
 }
 
-sub supertypes {
+sub getSupertypes { X3DPackage::Array( shift, 'ISA' ) }
+
+sub setSupertypes {
 	my $package = shift;
-
-	if (@_) {
-		$package->Weed::Package::base($_) foreach @_;
-		return;
-	}
-	else {
-		return @{ Weed::Package::isa($package) };
-	}
+	$package->X3DPackage::setBase($_) foreach @_;
+	return;
 }
 
-sub create {
-	my $name = shift;
-	eval "package $name;\n";
-	return Weed::Package::exists($name);
-}
+#sub create {
+#	my $name = shift;
+#	eval "package $name;\n";
+#	return X3DPackage::exists($name);
+#}
 
-sub base {
-	#Carp::carp ( "Weed::Package::alias" );
-	my $name = Weed::Package::name(shift);
+sub setBase {
+	#Carp::carp ( "X3DPackage::alias" );
+	my $name = X3DPackage::getName(shift);
 	my $base = shift;
-	
-	return if $name eq $base;
 
-	#unshift @{ Weed::Package::array( $name, "ISA" ) }, $base;
-	my $expression = Weed::Package::expression( $name, $base, @_ );
+	return if !$base || $name eq $base;
+
+	#unshift @{ X3DPackage::array( $name, "ISA" ) }, $base;
+	my $expression = X3DPackage::expression( $name, $base, @_ );
 	eval $expression;
 	if ($@) {
 		#printf "%s\n", $expression;
@@ -85,7 +116,7 @@ sub base {
 }
 
 # sub constants {
-# 	my $package   = Weed::Package::name(shift);
+# 	my $package   = X3DPackage::getName(shift);
 # 	my %constants = @_;
 # 	no strict 'refs';
 # 	while ( my ( $name, $value ) = each %constants ) {
@@ -94,26 +125,24 @@ sub base {
 # 	}
 # }
 
-*alias = \&base;
-
-sub isa { Weed::Package::array( shift, 'ISA' ) }
+#*alias = \&base;
 
 sub expression {
 	my $alias    = shift;
 	my $original = shift;
-	#Carp::carp ( "Weed::Package::expression", @_);
+	#Carp::carp ( "X3DPackage::expression", @_);
 
 	my $expression;
 
 	$expression .= "package $alias;\n";
-	$expression .= "use $original;\n" if $original ne 'main' && !Weed::Package::exists($original);
+	$expression .= "use $original;\n" if $original ne 'main' && !X3DPackage::exists($original);
 	$expression .= "use base '$original';\n";
 
 	if (@_) {
 		$expression .= "use strict;\n";
 		$expression .= "use warnings;\n";
 
-		$expression .= Weed::Package::statements( $original, @_ );
+		$expression .= X3DPackage::statements( $original, @_ );
 	}
 
 	#Carp::carp ( $expression );
@@ -132,11 +161,11 @@ sub _import {
 		$expression .= "use strict;\n";
 		$expression .= "use warnings;\n";
 
-		unless ( Weed::Package::exists($original) ) {
+		unless ( X3DPackage::exists($original) ) {
 			$expression .= "use $original;\n";
 		}
 
-		$expression .= Weed::Package::statements( $original, @_ );
+		$expression .= X3DPackage::statements( $original, @_ );
 	}
 
 	printf "%s\n", $expression;
@@ -163,7 +192,7 @@ sub statements {
 
 		if ( 'ARRAY' eq ref $_ ) {
 
-			$expression .= Weed::Package::statements( $original, @$_ );
+			$expression .= X3DPackage::statements( $original, @$_ );
 
 		}
 		elsif ( 'HASH' eq ref $_ ) {
@@ -214,75 +243,76 @@ sub get_rename_string {
 no strict 'refs';
 no warnings;
 
-sub scalar {
+sub Scalar : lvalue {
 	my ( $this, $name ) = @_;
-	my $property = sprintf '%s::%s', $this->Weed::Package::name, $name;
-	return \$$property;
+	my $property = sprintf '%s::%s', $this->X3DPackage::getName, $name;
+	$$property;
 }
 
 use warnings;
 
-sub array {
+sub Array : lvalue {
 	my ( $this, $name ) = @_;
-	my $property = sprintf '%s::%s', $this->Weed::Package::name, $name;
-	return \@$property;
+	my $property = sprintf '%s::%s', $this->X3DPackage::getName, $name;
+	@$property;
 }
 
-sub hash {
+sub Hash : lvalue {
 	my ( $this, $name ) = @_;
-	my $property = sprintf '%s::%s', $this->Weed::Package::name, $name;
-	return \%$property;
+	my $property = sprintf '%s::%s', $this->X3DPackage::getName, $name;
+	%$property;
 }
 
-sub can {
-	my ( $this, $name ) = @_;
-	my $property = sprintf "%s::%s::can::%s", __PACKAGE__, $this->Weed::Package::name, $name;
-
-	unless ( defined $$property ) {
-		$$property = [];
-		push @$$property, map { \&{"${_}::${name}"} }
-		  grep { exists &{"${_}::${name}"} } Weed::Package::self_and_superpath($this);
-	}
-
-	return @$$property;
-}
+# sub can {
+# 	my ( $this, $name ) = @_;
+# 	my $property = sprintf "%s::%s::can::%s", __PACKAGE__, $this->X3DPackage::getName, $name;
+# 
+# 	unless ( defined $$property ) {
+# 		$$property = [];
+# 		push @$$property, map { \&{"${_}::${name}"} }
+# 		  grep { exists &{"${_}::${name}"} } X3DPackage::getSelfAndSuperpath($this);
+# 	}
+# 
+# 	return @$$property;
+# }
 
 use strict 'refs';
 
-sub call {
-	my ( $this, $name ) = ( shift, shift );
-	return map { &$_( $this, @_ ) } Weed::Package::can( $this, $name );
-}
+#sub call {
+#	my ( $this, $name ) = ( shift, shift );
+#	return map { &$_( $this, @_ ) } X3DPackage::can( $this, $name );
+#}
 
-sub reverse_call {
-	my ( $this, $name ) = ( shift, shift );
-	return map { &$_( $this, @_ ) } reverse Weed::Package::can( $this, $name );
-}
+#sub reverse_call {
+#	my ( $this, $name ) = ( shift, shift );
+#	return map { &$_( $this, @_ ) } reverse X3DPackage::can( $this, $name );
+#}
 
-sub sub { ( caller( ( $_[1] || 0 ) + 1 ) )[3] }
+#sub sub { ( caller( ( $_[1] || 0 ) + 1 ) )[3] }
 
-sub stringify {
+sub toString {
 	my $package = shift;
 	my $level   = shift || 1;
 	my $string  = '';
 
-	$string .= $package->Weed::Package::name;
+	$string .= $package->X3DPackage::getName;
 
-	my $hierarchy = $package->Weed::Package::isa;
+	my $hierarchy = \X3DPackage::Array( $package, 'ISA' );
 
 	$string .= ' ';
 	$string .= '[';
 
 	if (@$hierarchy) {
-		$string .= ' ';
 
 		if ($#$hierarchy) {
 			$string .= "\n";
 			$string .= '  ' x $level;
+		} else {
+			$string .= ' ';
 		}
 
 		$string .= join "\n" . ( '  ' x $level ), map {
-			$_->Weed::Package::stringify( $level + 1 );
+			$_->X3DPackage::toString( $level + 1 );
 		} @$hierarchy;
 
 		if ($#$hierarchy) {
