@@ -43,7 +43,6 @@ our @EXPORT = qw(
   $_exposedField
   $_field
 
-  $_period
   $_open_parenthesis
   $_close_parenthesis
   $_open_brace
@@ -51,6 +50,10 @@ our @EXPORT = qw(
   $_close_brace_test
   $_open_bracket
   $_close_bracket
+  $_open_angle_bracket
+  $_close_angle_bracket
+
+  $_period
   $_brackets
   $_colon
   $_colon_test
@@ -74,6 +77,9 @@ our @EXPORT = qw(
   $_enum
 
   $_FieldDefinition
+
+  $_RestrictedId
+  $_week_hash
 );
 #$Id
 
@@ -109,20 +115,31 @@ our $vrmlScriptFieldType  = join '|', @VrmlScriptFieldTypes;
 our $fieldType            = join '|', @FieldTypes;
 
 # Terminal symbols
-our $period            = '\\' . $_period_;
-our $open_parenthesis  = '\\' . $_open_parenthesis_;
-our $close_parenthesis = '\\' . $_close_parenthesis_;
-our $open_brace        = '\\' . $_open_brace_;
-our $close_brace       = '\\' . $_close_brace_;
-our $open_bracket      = '\\' . $_open_bracket_;
-our $close_bracket     = '\\' . $_close_bracket_;
-our $colon             = '\\' . $_colon_;
+our $open_parenthesis    = '\\' . $_open_parenthesis_;
+our $close_parenthesis   = '\\' . $_close_parenthesis_;
+our $open_brace          = '\\' . $_open_brace_;
+our $close_brace         = '\\' . $_close_brace_;
+our $open_bracket        = '\\' . $_open_bracket_;
+our $close_bracket       = '\\' . $_close_bracket_;
+our $open_angle_bracket  = '\\' . $_open_angle_bracket_;
+our $close_angle_bracket = '\\' . $_close_angle_bracket_;
+our $period              = '\\' . $_period_;
+our $colon               = '\\' . $_colon_;
+
+#
+our $exclamation_mark = '\\' . $_exclamation_mark_;
+our $swung_dash       = '\\' . $_swung_dash_;
 
 # Other Symbols
 our $IdFirstChar = '[^\x30-\x39\x00-\x20\x22\x23\x27\x2b\x2c\x2d\x2e\x5b\x5c\x5d\x7b\x7d\x7f]{1}';
 our $IdRestChars = '[^\x00-\x20\x22\x23\x27\x2c\x2e\x5b\x5c\x5d\x7b\x7d\x7f]';
 our $Id          = "$IdFirstChar$IdRestChars*";
 
+#Concept
+our $RestrictedIdFirstChar = '[^\x30-\x39\x00-\x23\x27\x2b\x2c\x2d\x2e\x5b\x5c\x5d\x7b\x7d-\x7f()]{1}';
+our $RestrictedId          = "$RestrictedIdFirstChar$IdRestChars*";
+our $_week_hash            = qr.\G$whitespace*$swung_dash$open_brace.so;
+
 #our $FieldName  = "[a-z]{1}[a-zA-Z_]*";
 #our $_FieldName = qr.\G($FieldName).so;
 
@@ -165,25 +182,29 @@ our $_exposedField   = qr.\G$whitespace*$_exposedField_$whitespace+.so;
 our $_field          = qr.\G$whitespace*$_field_$whitespace+.so;
 
 # Terminal symbols
-our $_period            = qr.\G$period.so;
-our $_open_parenthesis  = qr.\G$whitespace*$open_parenthesis.so;
-our $_close_parenthesis = qr.\G$whitespace*$close_parenthesis.so;
-our $_open_brace        = qr.\G$whitespace*$open_brace.so;
-our $_close_brace       = qr.\G$whitespace*$close_brace.so;
-our $_close_brace_test  = qr.\G(?=$whitespace*$close_brace).so;
-our $_open_bracket      = qr.\G$whitespace*$open_bracket.so;
-our $_close_bracket     = qr.\G$whitespace*$close_bracket.so;
-our $_brackets          = qr.\G$whitespace*$open_bracket$whitespace*$close_bracket.so;    # []
-our $_colon             = qr.\G$whitespace*$colon.so;
-our $_colon_test        = qr.\G$whitespace+$colon$whitespace+.so;
+our $_open_parenthesis    = qr.\G$whitespace*$open_parenthesis.so;
+our $_close_parenthesis   = qr.\G$whitespace*$close_parenthesis.so;
+our $_open_brace          = qr.\G$whitespace*$open_brace.so;
+our $_close_brace         = qr.\G$whitespace*$close_brace.so;
+our $_close_brace_test    = qr.\G(?=$whitespace*$close_brace).so;
+our $_open_bracket        = qr.\G$whitespace*$open_bracket.so;
+our $_close_bracket       = qr.\G$whitespace*$close_bracket.so;
+our $_open_angle_bracket  = qr.\G$whitespace*$open_angle_bracket.so;
+our $_close_angle_bracket = qr.\G$whitespace*$close_angle_bracket.so;
+
+our $_period     = qr.\G$period.so;
+our $_brackets   = qr.\G$whitespace*$open_bracket$whitespace*$close_bracket.so;    # []
+our $_colon      = qr.\G$whitespace*$colon.so;
+our $_colon_test = qr.\G$whitespace+$colon$whitespace+.so;
 
 # Other Symbols
-our $_Id        = qr.\G$whitespace*($Id).so;
-our $_double    = qr.\G$whitespace*($double).so;
-our $_fieldType = qr.\G$whitespace*($fieldType).so;
-our $_float     = qr.\G$whitespace*($float).so;
-our $_int32     = qr.\G$whitespace*($int32).so;
-our $_string    = qr.\G$whitespace*"($string?)(?<!\\)".so;
+our $_Id           = qr.\G$whitespace*($Id).so;
+our $_RestrictedId = qr.\G$whitespace*($RestrictedId).so;
+our $_double       = qr.\G$whitespace*($double).so;
+our $_fieldType    = qr.\G$whitespace*($fieldType).so;
+our $_float        = qr.\G$whitespace*($float).so;
+our $_int32        = qr.\G$whitespace*($int32).so;
+our $_string       = qr.\G$whitespace*"($string?)(?<!\\)".so;
 
 our $_Body = qr.\G$whitespace*($string?)$whitespace*(?=$close_brace).so;
 
