@@ -8,17 +8,23 @@ our @EXPORT = qw(
   $_space_
   $_break_
 
-  $_period_
   $_open_parenthesis_
   $_close_parenthesis_
   $_open_brace_
   $_close_brace_
   $_open_bracket_
   $_close_bracket_
+  $_open_angle_bracket_
+  $_close_angle_bracket_
+
+  $_period_
   $_colon_
   $_comma_
   $_comment_
 
+  $_swung_dash_
+  $_exclamation_mark_
+
   $_in_
   $_out_
 
@@ -58,16 +64,23 @@ our $_space_ = ' ';
 our $_break_ = "\n";
 
 # Terminal symbols
-our $_period_            = '.';
-our $_open_parenthesis_  = '(';
-our $_close_parenthesis_ = ')';
-our $_open_brace_        = '{';
-our $_close_brace_       = '}';
-our $_open_bracket_      = '[';
-our $_close_bracket_     = ']';
-our $_colon_             = ':';
-our $_comma_             = ',';
-our $_comment_           = '#';
+our $_open_parenthesis_    = '(';
+our $_close_parenthesis_   = ')';
+our $_open_brace_          = '{';
+our $_close_brace_         = '}';
+our $_open_bracket_        = '[';
+our $_close_bracket_       = ']';
+our $_open_angle_bracket_  = '<';
+our $_close_angle_bracket_ = '>';
+
+our $_period_  = '.';
+our $_colon_   = ':';
+our $_comma_   = ',';
+our $_comment_ = '#';
+
+#
+our $_exclamation_mark_ = '!';
+our $_swung_dash_       = '~';
 
 # concept
 our $_in_  = 'in';
