@@ -1,15 +1,13 @@
 package Weed::Tie::WeakHash;
 use Weed::Perl;
 
-our $VERSION = '0.009';
-
 use Tie::Hash;
 use base 'Tie::StdHash';
 
 use Scalar::Util 'weaken';
 
 sub new {
-	tie my (%hash), shift;
+	tie my %hash, shift;
 	return \%hash;
 }
 
