@@ -37,26 +37,42 @@ sub negate {
 
 sub add {
 	my ( $a, $b ) = @_;
-	return $a->new( [
+	return ref $b ?
+	  $a->new( [
 			$a->[0] + $b->[0],
 			$a->[1] + $b->[1],
 			$a->[2] + $b->[2],
 			$a->[3] + $b->[3],
-	] );
+		] )
+	  :
+	  $a->new( [
+			$a->[0] + $b,
+			$a->[1] + $b,
+			$a->[2] + $b,
+			$a->[3] + $b,
+	  ] );
 }
 
 use overload '+=' => sub {
 	my ( $a, $b ) = @_;
-	$a->[0] += $b->[0];
-	$a->[1] += $b->[1];
-	$a->[2] += $b->[2];
-	$a->[3] += $b->[3];
+	if ( ref $b ) {
+		$a->[0] += $b->[0];
+		$a->[1] += $b->[1];
+		$a->[2] += $b->[2];
+		$a->[3] += $b->[3];
+	} else {
+		$a->[0] += $b;
+		$a->[1] += $b;
+		$a->[2] += $b;
+		$a->[3] += $b;
+	}
 	return $a;
 };
 
 sub subtract {
 	my ( $a, $b, $r ) = @_;
-	return $a->new( [
+	return ref $b ?
+	  $a->new( [
 			$r ? (
 				$b->[0] - $a->[0],
 				$b->[1] - $a->[1],
@@ -68,15 +84,27 @@ sub subtract {
 				$a->[2] - $b->[2],
 				$a->[3] - $b->[3],
 			  ) ] )
-	  ;
+	  : $a->new( [
+			$a->[0] - $b,
+			$a->[1] - $b,
+			$a->[2] - $b,
+			$a->[3] - $b,
+	  ] );
 }
 
 use overload '-=' => sub {
 	my ( $a, $b ) = @_;
-	$a->[0] -= $b->[0];
-	$a->[1] -= $b->[1];
-	$a->[2] -= $b->[2];
-	$a->[3] -= $b->[3];
+	if ( ref $b ) {
+		$a->[0] -= $b->[0];
+		$a->[1] -= $b->[1];
+		$a->[2] -= $b->[2];
+		$a->[3] -= $b->[3];
+	} else {
+		$a->[0] -= $b;
+		$a->[1] -= $b;
+		$a->[2] -= $b;
+		$a->[3] -= $b;
+	}
 	return $a;
 };
 
